import { TransformOptions } from '@babel/core';
declare type BabelOptions = Omit<TransformOptions, 'fileName' | 'minify' | 'include' | 'exclude'>;
declare namespace compluginBabel {
    interface Options extends Omit<BabelOptions, 'wrapPluginVisitorMethod'> {
        /**
         * A minimatch pattern, or array of patterns,
         * which specifies the files in the build the plugin should ignore.
         *
         * When relying on Babel configuration files you can only exclude additional files with this option,
         * you cannot override what you have configured for Babel itself.
         *
         * @default [/\.(tsx?|jsx?|mjs)$/i]
         */
        include?: (string | RegExp)[];
        /**
         * A minimatch pattern, or array of patterns, which specifies the files in the build the plugin should operate on.
         * When relying on Babel configuration files you cannot include files already excluded there.
         */
        exclude?: (string | RegExp)[];
        /**
         * Cache the transform results of Babel.
         *
         * @default true
         */
        cache?: boolean;
        /**
         * Use worker threads for parallel transformations.
         * Enabling parallel mode is only recommended for large projects.
         * @default false
         */
        parallel?: boolean;
    }
}
declare const compluginBabel: import("complugin").CompluginInstance<compluginBabel.Options>;
export default compluginBabel;
